<?php

namespace Assetdocs\Item\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Item\Interfaces\ItemRepositoryInterface;
use Assetdocs\Item\Repositories\Presenter\ItemItemTransformer;

/**
 * Pubic API controller class.
 */
class ItemApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Item\Interfaces\ItemRepositoryInterface $item
     *
     * @return type
     */
    public function __construct(ItemRepositoryInterface $item)
    {
        $this->middleware('api');

        $this->repository = $item;
        parent::__construct();
    }

    /**
     * Show item's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $items = $this->repository
            ->pushCriteria(new \Assetdocs\Item\Repositories\Criteria\ItemPublicCriteria())
            ->setPresenter('\\Assetdocs\\Item\\Repositories\\Presenter\\ItemListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $items['code'] = 2000;
        return response()->json($items)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show item.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $item = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($item)) {
            $item         = $this->itemPresenter($module, new ItemItemTransformer);
            $item['code'] = 2001;
            return response()->json($item)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
