<?php

namespace Assetdocs\Item\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Item\Models\Item;

class ItemPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the item.
     *
     * @param User $user
     * @param Item $item
     *
     * @return bool
     */
    public function view(User $user, Item $item)
    {
        if ($user->canDo('item.item.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $item->user_id;
    }

    /**
     * Determine if the given user can create a item.
     *
     * @param User $user
     * @param Item $item
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('item.item.create');
    }

    /**
     * Determine if the given user can update the given item.
     *
     * @param User $user
     * @param Item $item
     *
     * @return bool
     */
    public function update(User $user, Item $item)
    {
        if ($user->canDo('item.item.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $item->user_id;
    }

    /**
     * Determine if the given user can delete the given item.
     *
     * @param User $user
     * @param Item $item
     *
     * @return bool
     */
    public function destroy(User $user, Item $item)
    {
        if ($user->canDo('item.item.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $item->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
